@@ -50,12 +50,10 @@ GType            gnome_settings_plugin_info_get_type           (void) G_GNUC_CON
 
 GnomeSettingsPluginInfo *gnome_settings_plugin_info_new_from_file (const char *filename);
 
-void             gnome_settings_plugin_info_set_settings_prefix (GnomeSettingsPluginInfo *info, const char *settings_prefix);
 gboolean         gnome_settings_plugin_info_activate        (GnomeSettingsPluginInfo *info);
 gboolean         gnome_settings_plugin_info_deactivate      (GnomeSettingsPluginInfo *info);
 
 gboolean         gnome_settings_plugin_info_is_active       (GnomeSettingsPluginInfo *info);
-gboolean         gnome_settings_plugin_info_get_enabled     (GnomeSettingsPluginInfo *info);
 gboolean         gnome_settings_plugin_info_is_available    (GnomeSettingsPluginInfo *info);
 
 const char      *gnome_settings_plugin_info_get_name        (GnomeSettingsPluginInfo *info);
@@ -66,9 +64,6 @@ const char      *gnome_settings_plugin_info_get_copyright   (GnomeSettingsPlugin
 const char      *gnome_settings_plugin_info_get_location    (GnomeSettingsPluginInfo *info);
 int              gnome_settings_plugin_info_get_priority    (GnomeSettingsPluginInfo *info);
 
-void             gnome_settings_plugin_info_set_priority    (GnomeSettingsPluginInfo *info,
-                                                             int                      priority);
-
 G_END_DECLS
 
 #endif  /* __GNOME_SETTINGS_PLUGIN_INFO_H__ */
