@@ -69,11 +69,11 @@ typedef enum {
         MAGNIFIER_ZOOM_IN_KEY,
         MAGNIFIER_ZOOM_OUT_KEY,
         POWER_KEY,
-        SLEEP_KEY,
         SUSPEND_KEY,
         HIBERNATE_KEY,
         SCREEN_BRIGHTNESS_UP_KEY,
         SCREEN_BRIGHTNESS_DOWN_KEY,
+        SCREEN_BRIGHTNESS_CYCLE_KEY,
         KEYBOARD_BRIGHTNESS_UP_KEY,
         KEYBOARD_BRIGHTNESS_DOWN_KEY,
         KEYBOARD_BRIGHTNESS_TOGGLE_KEY,
